@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher;
 BEGIN {
-  $WWW::FetchStory::Fetcher::VERSION = '0.1002';
+  $WWW::FetchStory::Fetcher::VERSION = '0.1003';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1002
+version 0.1003
 
 =head1 DESCRIPTION
 
@@ -179,8 +179,8 @@ sub fetch {
     my $toc_content = $self->get_toc($args{url});
     my %story_info = $self->parse_toc(content=>$toc_content,
 				      url=>$args{url});
-    my $now = time2str('%Y-%m-%d %H:%M', time);
-    $story_info{fetched} = $now;
+    my $today = time2str('%Y-%m-%d', time);
+    $story_info{fetched} = $today;
 
     warn Dump(\%story_info) if $self->{verbose};
 
